import { baseFetch, statisticsFetch } from '../../api/fetch';
import { formatTime } from '../../utils/util';

// miniprogram/pages/userGrowth/userGrowth.js
Page({
  onLoad() {
    this.initData();
    this.fetchAreaList();
  },
  /**
   * 页面的初始数据
   */
  data: {
    month: '',
    areaId: 0,
    areaList: [],
    growthList: [],
    customerCount: 0,
    activeCount: 0,
  },
  initData() {
    let time = formatTime(new Date());
    console.log(time);
    this.setData!({ month: time.slice(0, 7) }, () => {
      this.fetchList();
    });
  },
  fetchAreaList() {
    baseFetch({
      url: '/dcxy/baseArea/queryAll',
    })
      .then(res => {
        if (res.data) {
          this.setData!({
            areaList: res.data,
          });
        } else {
          this.setData!({
            areaList: [],
          });
        }
      })
      .catch(err => {
        console.log(err);
      });
  },
  fetchList(entity?: { areaId?: number; month?: string }) {
    this.fetchUserData(entity);
  },
  fetchUserData(entity) {
    let reqBody = {
      year: this.data.month.slice(0, 4),
      isAdmin: 1,
      ...entity,
    };
    if (this.data.areaId) reqBody.areaId = this.data.areaId;
    statisticsFetch({
      url: '/dcxy/reportInfo/queryReportList',
      data: reqBody,
    })
      .then(res => {
        console.log(res);
        const { customerCount, dayVos, activeCount } = res.data;
        let dayList = new Array(31)
          .fill({
            count: 0,
          })
          .map((v, idx) => ({ ...v, days: idx + 1 }));

        if (dayVos && dayVos.length) {
          let oList = dayVos;
          for (let index = 0; index < oList.length; index++) {
            const element = oList[index];
            let daysIndex = element.completeAt.slice(-2);
            dayList[daysIndex] = {
              ...dayList[daysIndex],
              count: element.count,
            };
          }
        }
        console.log('dayList:', dayList);
        this.setData!({
          growthList: dayList,
          customerCount: customerCount ? customerCount : 0,
          activeCount: activeCount ? activeCount : 0,
        });
      })
      .catch(err => {
        console.log(err);
      });
  },
  areaChangeHandle() {},
});
